      SUBROUTINE BVAL(M)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C   PARTICLE BEAM DEFINITION
C   COMPUTES KINEMATICS AND UNNORMALIZED EMITTANCES.
C   IF INPUT EMITTANCES ARE NORMALIZED, UNNORMALIZED VALUES
C WILL BE CALCULATED.
C   UNNORMALIZED VALUES WILL BE STORED FOR LATER USE.
C..........................................................
C   NAM  BVAL   KA   KB// PT    A  EPSX   EPSY  EPSL   SIGL
C.........................................................
C   NAM   BVAL        //           EPSX   EPSY  EPSL   SIGL
C   KIN   BVAL            P     A  EPSX   EPSY  EPSL   SIGL
C   KNM   BVAL   1   1//  T     A  EPSX   EPSY  EPSL   SIGL

C        PT = EITHER P, T OR BLANK WHERE
C          P = MOMENTUM GEV/C
C          T = KINETIC ENERGY GEV
C          A = ATOMIC WEIGHT
C              IF A = 0 OR BLANK, ELECTRON MASS IS ASSUMED.
C          EMITTANCES (EPS) IN MM-MRAD
C          SIGL (MM)

C        IF KA=0 OR BLANK, 1ST PARAMETER IS P.
C        IF KA NOT 0 (OR BLANK), 1ST PARAMETER IS T.

C        IF KB = 0 (OR BLANK), THE NEXT CALL TO CYC WILL
C        PRINT ETAS = -VP(5)
C        IF KB NOT 0 , THE NEXT CALL TO CYC WILL
C        PRINT ETAT =VP(5) -S/GAMMASQ.

C   UNNORMALIZED INPUT -- WHEN PT=0, THE EPSX ETC. ON THE INPUT CARD
C                         REPRESENT UNNORMALIZED EMITTANCES AND NO
C                          KINEMATIC CALCULATIONS ARE DONE.
C    NORMALIZED INPUT -- WHEN PT NOT 0 AND EPSX,ETC. ARE PRESENT.


      include 'ccc/binff.ccc'
C BINFF.CCC
C  INFMAX=LNFSIZ INSIDE PROGRAM
C      PARAMETER (LNFSIZ=1000,IFFSIZ=24,IFCSIZ=6)
C      PARAMETER (LNCSIZ=1000,IXFLG=-LNFSIZ-1)
C      COMMON /BINFF/INFF(IFFSIZ,LNFSIZ)
C      COMMON /CINFF/ CINFF(IFCSIZ,LNCSIZ)
C      CHARACTER CINFF*5

      include 'ccc/files.ccc'
C      COMMON/FILES/INFILE,OUT3,IFILE,OFILE,PRFILE,PLFILE,
C     1    ORB1,JBIS,CYBO,FILE11
C      INTEGER OUT3,OFILE,PRFILE,PLFILE,ORB1,CYBO,FILE11

      include 'ccc/kinet.ccc'
C KINET.CCC
C      COMMON/KINET/KNFLAG,TK,PKIN,GAM,BETT,BETGAM,BRHO
C      LOGICAL KNFLAG

      DIMENSION PAR(6),EM(4)
      EQUIVALENCE (EPSX,EM(1)),(EPSY,EM(2)),(EPSL,EM(3)),(SIGP,EM(4))
      DATA E0,RME,CONK/ .9382796D0, 5.110034D-4, 3.33564095D0 /
      KA = INFF(4,M)
      KB = INFF(5,M)
      CALL GETFL(M,1,6,PAR)
      IF (PAR(1).EQ.0)  GO TO 22
      A = PAR(2)
      IF (A.EQ.0)  A = RME
      AMPC2 = A*E0
      AMPC2R = 1/AMPC2
      IF (KA.NE.0)  GO TO 15
C  1ST PARAM IS P
      P = PAR(1)
      BETGAM = P*AMPC2R
      GAM = SQRT(BETGAM*BETGAM + 1)
      TK = AMPC2*(GAM-1)
      GO TO 20
C  1ST PARAM IS T
 15   TK = PAR(1)
      GAM = TK*AMPC2R + 1
      BETGAM = SQRT(GAM*GAM - 1)
      P = AMPC2*BETGAM
 20   BETT = BETGAM/GAM
      BRHO = P*CONK
      IF (KB.NE.0)  KNFLAG = .TRUE.
      WRITE (OUT3,101)
      CALL DASH1
      WRITE (OUT3,100)  P,TK,A,BRHO,BETT,GAM,BETGAM
      IF ((PAR(3).EQ.0).AND.(PAR(4).EQ.0).AND.(PAR(5).EQ.0).AND.
     1  (PAR(6).EQ.0))  RETURN
      BETGMR = 1/BETGAM
      EPSX = PAR(3)*BETGMR
      EPSY = PAR(4)*BETGMR
      EPSL = PAR(5)*BETGMR
      GO TO 25
C   ALREADY UNNORMALIZED CASE
 22   EPSX = PAR(3)
      EPSY = PAR(4)
      EPSL = PAR(5)
 25   SIGL = PAR(6)
      SIGP = EPSL/SIGL
      CALL STOQ (M,1,4,EM)
      WRITE (OUT3,105) EPSX,EPSY,EPSL,SIGL,SIGP
      CALL DASH1

 100  FORMAT (8X,'P = ',F10.5,' GEV/C',6X,'T = ',
     1  F10.5,' GEV',12X,'A = ',F10.5,6X,'BRHO = ',F10.5,/
     2  5X,'BETA = ',E15.8,3X,'GAMMA = ',E15.8,3X,
     3  'BETAGAMMA = ',E15.8)
 101   FORMAT (' ')
 105  FORMAT (/5X,'EMITTANCES UNNORMALIZED  (MM-MRAD)'/
     1   8X,'EPSX = ',F10.6,4X,'EPSY = ',F10.6,4X,'EPSL = ',
     2   F10.6,10X,'SIGL = ',F10.6,1X,'MM',4X,'SIGP = ',F10.6,
     3  ' (0/00)')
      RETURN
      END
