      SUBROUTINE CYAE(M)

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

C       USING BETATRON FUNCTIONS, COMPUTES BEAM ENVELOPES ALONG BEAM
C  LINE FROM PREVIOUSLY CALCULATED EMITTANCES, EPSX,EPSY,DP/P.

C....................................................
C NAME CYAE  KA    /BL  BEAM  KSQ       EPXCO     EPYCO
C......................................................
C  BL = BEAMLINE NAME
C  BEAM = NAME OF BVAL OR CYEM THAT GIVES EMITTANCES AND DP/P
C  KSQ = EPS/EPS0, WHERE EPS0 IS EMITTANCE FROM BVAL (SIG**2/BETA)
C                  AND EPS IS EMITTANCE TO BE USED BY CYAE.
C                  XB AND XP ARE THUS MULTIPLIED BY SQRT(KSQ).
C  EPXCO, EPYCO = EQUIVALENT EMITTANCES THAT GIVE CLOSED ORBIT DISPLACEMENTS
C  KA = 0 OR NON-0 ---  ADD BETATRON AND MOMENTUM DISPLACEMENTS IN QUADRATURE
C                   OR ALGEBRAICALLY.

      include 'ccc/binff.ccc'

      include 'ccc/bmi.ccc'

      include 'ccc/dim.ccc'

      include 'ccc/const.ccc'

      include 'ccc/files.ccc'

      DIMENSION P(4),BETX(9),BETY(9),ML(3)
      EQUIVALENCE (EPX,P(1)),(EPY,P(2)),(EPL,P(3)),(DPP,P(4))
      EQUIVALENCE (BX,BETX(2)),(GX,BETX(4)),(DX,BETX(5)),(DDX,BETX(6)),
     1            (BY,BETY(2)),(GY,BETY(4)),(DY,BETY(5)),(DDY,BETY(6))

      CHARACTER(5) MNAME,MAT

C                  GET DATA  EPX,EPY AND DP/P
      MD = MDAT(M,2)
      CALL GETQ(MD,1,4,P)

C     KA DETERMINES CALCULATION FOR XTOT AND XTOT PR
      KA = INFF(4,M)

C  GET BEAM LINE, MAKE MILIST AND MULTIPLY MATRICES
C        K IS NUMBER OF ELEMENTS IN BEAM
      MB = MDAT(M,1)
      K = INFF(17,MB)
      MS = MEND - 1
      CALL MIFILL (MB,1,K,NELS,MI,MISIZ)
      CALL MMM (MS,NELS,MI)
      KW = NELS + 1
      MI(KW) = MI(1)
      I = 0
      EL = 0
      FL = 0
      MAT = IBLNK

      XKSQ=FLDAT(M,1)
      RK=SQRT(XKSQ)
      EPXCO=FLDAT(M,2)
      EPYCO=FLDAT(M,3)
      RX=SQRT(EPXCO/EPX)
      RY=SQRT(EPYCO/EPY)

C    PRINT TABLE HEADING AND SIGX AND SIGY, AS DEFINED BY FACTK
      CALL DASH1
      WRITE(OUT3,1) P(1),EPXCO,P(3),P(2),EPYCO,P(4)
      IG = 1
      IF (KA.EQ.0) IG = 2
      IF (IG.EQ.1) GOTO 104
      IF (IG.EQ.2) GOTO 105
 104  WRITE (OUT3,6)
      GO TO 106
 105  WRITE (OUT3,8)
 106  WRITE(OUT3,2) RK
      WRITE(OUT3,11)

 115   CONTINUE
      CALL BET(MS,BETX,BETY,1)
C                  COMPUTE AND PRINT BEAM ENVELOPES
      X=SQRT(EPX*BX)*RK
      Y=SQRT(EPY*BY)*RK
      XP=DX*DPP
      YP=DY*DPP
      XCO=RX*X
      YCO=RY*Y
      XPR=SQRT(EPX*GX)*RK
      YPR=SQRT(EPY*GY)*RK
      XPPR=DDX*DPP*RK
      YPPR=DDY*DPP*RK
      XCOPR=RX*XPR
      YCOPR=RY*YPR
      IF (IG.EQ.1) GOTO 116
      IF (IG.EQ.2) GOTO 117
 116  XTOT = X + ABS(XP)
      XPRTOT = XPR + ABS(XPPR)
      YTOT = Y + ABS(YP)
      YPRTOT = YPR + ABS(YPPR)
      GO TO 118
 117  CONTINUE
      XTOT = SQRT( X * X + XP * XP )
      XPRTOT = SQRT( XPR*XPR + XPPR*XPPR)
      YTOT = SQRT(Y*Y + YP*YP)
      YPRTOT = SQRT(YPR*YPR + YPPR*YPPR)
 118  CONTINUE
      XTOT=XTOT+XCO
      YTOT=YTOT+YCO
      XPRTOT=XPRTOT+XCOPR
      YPRTOT=YPRTOT+YCOPR
      EL = EL + FL
      WRITE(OUT3,12) I,MAT,EL,X,XP,XCO,XTOT,Y,YP,YCO,YTOT,XPRTOT,YPRTOT

      I = I + 1
      IF (I.EQ.KW) GO TO 125
      NI = MI(I)
      CALL GETQ(NI,1,1,FL)
      MAT = MNAME(NI)
      ML(1) = - NI
      ML(2) = MS
      ML(3) = NI
      CALL MMM(MS,3,ML)
      GO TO 115

 125  CALL DASH1
      RETURN

C***********************************************************************

 1      FORMAT (3X,'BEAM ENVELOPES (MM,MRAD)'/
     1  5X,'EMITTANCES (MM-MRAD) --- EPSX = ',F10.6,5X,'EPSXCO = ',
     2  F10.6,5X,'EPSL = ',F13.6/30X,'EPSY = ',F10.6,5X,'EPSYCO = ',
     3  F10.6,5X,'SIGP = ',F10.6,' (0/00)')

 6    FORMAT (5X,'XTOT = XB + XP + XCO,   ETC.')
 8    FORMAT (5X,'XTOT = SQRT(XB*XB + XP*XP) + XCO,   ETC.')

 2    FORMAT('+',99X,'DISPLACEMENT = ',F5.2,'*','SIGMA')
 10   FORMAT (/3X,'POS',10X,'S',8X,'X',7X,'X PR',6X,
     1 'XP',5X,'XP PR',4X,'XTOT',3X,'XTOT PR',5X,'Y',7X,
     2 'Y PR',5X,'YP',6X,'YP PR',5X,'YTOT',3X,'YTOT PR'/1X,131('-'))
 11   FORMAT(/3X,'POS',10X,'S',13X,'XB',7X,'XP',7X,'XCO',6X,'XTOT',
     1                         10X,'YB',7X,'YP',7X,'YCO',6X,'YTOT',
     2                         10X,'XPRTOT',3X,'YPRTOT'/1X,131('-'))
 12   FORMAT(' ',I5,1X,A5,F9.4,5X,4F9.4,5X,4F9.4,5X,2F9.4)

      END
