      SUBROUTINE CYEM1(M)

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

C ***  NOTE ******
C ** THIS IS ORIGINAL CYEM ROUTINE, TO HANDLE BOTH BEAM LINES AND FXPT
C **  IT IS CALLED WHEN CYEM1 COMMAND IS ISSUED.
C  CALCULATES ELECTRON INTEGRALS, RF OUTPUT, ELECTRON EMITTANCE FACTORS
C  CALCULATES HORIZONTAL INTEGRALS ONLY.  
C  USE THIS ONE WHEN BL REFERS TO A FXPT COMMAND
C  USE CYEM FOR  HORIZONTAL & VERTICAL.  FOR BEAM LINE INPUT ONLY.
C
C  EPS  CYEM1 KA  KB  // BL  E  R  F  V  K
C
C  KA = OUTPUT OPTION
C  KB = NUMBER OF SUPERPERIODS
C       IF BL IS A FXPT INSTRUCTION, BEAM LINE AND KB ARE TAKEN FROM
C       THOSE OF THE FXPT INSTRUCTION.
C  BL = NAME OF BEAM LINE (BML INSTRUCTION) OR OF FXPT INSTRUCTION
C   E = ELECTRON BEAM ENERGY (GEV)
C   R = MACHINE RADIUS (M)
C   F = RF FREQUENCY (MHZ)
C   V = RF VOLTS/TURN (MV)
C   K = COUPLING COEFFICIENT (SQRT(EPY/EPX))
C  KA = OUTPUT OPTION. IGNORED (SET TO 0) IF BL IS A BML INST
C  KA = 0,1 PRINT ONLY AT START OF BEAM LINE
C  KA = 2,3,4 PRINT AT EVERY ELEMENT
C  KA = EVEN, BETATRON PART OF SIGMA MATRIX
C  KA = ODD,  TOTAL SIGMA MATRIX
C  KA = 2,3   SIGMA MATRIX LONG OUTPUT
C  KA = 4     AIJ, BIJ LONG OUTPUT
C
C  KA POSITIVE --- PRINTS RII, TIJ. RII = SQRT(SIGMA(I,I))
C                  TIJ = ARCTAN(SIJ/SII - SJJ) / 2
C                  RII IS THE PROJECTION OF BEAM ELLIPSE ON I AXIS
C                  TIJ IS TILT OF ELLIPSE PROJECTION IN I-J PLANE
C  KA NEGATIVE --- PRINTS SIJ = SIGMA(I, J) FOR ALL ELEMENTS
C                  AIJ = 4 X REAL(F1I* X F1J),BIJ = 4 X REAL(F3I* X F3J)
C                  F=INVERSE(E),F=MATRIX OF EIGENVECTORS,FIJ*X CONJ(FIJ)
C                  SIGMA = INVERSE(A/EP1 + B/EP3)
C                  EP1, EP3 = GENERALIZED EMITTANCES (SIGMA**2/BETA)
C                  STOTIJ = SBETIJ + ETAJ*SIGDP**2
C                  IF EP3 = 0, SETS EP3 = EPY
C                  IF KAPPA = 0 AND BL = FXPT INSTR, SETS KAPPA=E-04
C

      include 'ccc/bstore.ccc'

      include 'ccc/binff.ccc'

      include 'ccc/bmi.ccc'

      include 'ccc/dim.ccc'

      include 'ccc/const.ccc'

      include 'ccc/files.ccc'

      include 'ccc/seed.ccc'

      DIMENSION BETX(9),BETY(9),PAR(5),P(6),EM(4),ML(3)
      DIMENSION EV(4,8),VZ(7,7),VW(7),RW(3),AA(4,4),BB(4,4),CC(4,8)
      DIMENSION RX(2,3),RY(2,3)
      DIMENSION EI(2)
      DOUBLE PRECISION I41,I43,I51,I53,J1,J3,J6,K,KSQ,LH
      DOUBLE PRECISION I1,I2,I3,I4,I5,L,KX,KK,N,LMTOT,K3R,JE,JX,JZ
      COMPLEX(KIND(0D0)) EV,DET,EJ1,EJ3,EK1,EK3,EI
      EQUIVALENCE (L,P(1)),(DB,P(2)),(BRHO,P(3)),(BZ,P(4)),(OM,P(4))
      EQUIVALENCE (GAM,BETX(4))

      EQUIVALENCE (PSI,XI)
      EQUIVALENCE (EPX,EM(1)),(EPY,EM(2)),(DPP,EM(3)),(EPLN, EM(4))
      EQUIVALENCE (B,BETX(2)),(A,BETX(3)),(E,BETX(5)),(F,BETX(6))
      EQUIVALENCE (PC,PAR(1)),(R,PAR(2)),(FREQ,PAR(3)),(V0,PAR(4)),
     1    (FKAP,PAR(5))
      EQUIVALENCE (ANG0,IANG0),  (ANG1,IANG1)

      LOGICAL BSW, LONG,FLAG,SIGFLG
      CHARACTER(5) IOPMB,IOP,MATI

      DATA CGAM,CQP,C,JE,JX,JZ
     1 / 8.846002206D-5, 1.467471313D-6, 2.997925D8, 2., 1., 1. /
      DATA RME/.0005110041D0/
      DATA RW/3*0.0D0/

      NRN = NRZZ

C     GET DATA  P/C,R,FREQ,VRF,KAPPA
C     UNITS ---   GEV/C, METERS, MHZ, MV
      CALL GETFL(M,1,5,PAR)
      FREQ = FREQ*1.D6
      V0 = V0*1.D-3

C     GET BEAM LINE, MAKE MI LIST AND MULTIPLY MATRICES
C     K IS NUMBER OF ELEMENTS IN BEAM LINE
      MB = MDAT(M,1)
      KA = 0
      KB = INFF(5,M)
      FLAG = .FALSE.
      MS = MEND - 1
      IOPMB = CINFF(1,MB)
      NGO=1
      IF (IOPMB.EQ.'FXPT') NGO=2
      CALL DASH1
      WRITE (OUT3,13)
      IF (NGO.EQ.1) GOTO 51
 52   MFX=MB
      MB=MDAT(MFX,2)
      NP=MDAT(MFX,1)
      KA = INFF(4,M)
      SIGFLG = .FALSE.
      IF (KA .GE. 0) GO TO 55
      SIGFLG = .TRUE.
      KA = -KA
 55   CONTINUE
      KAF = INFF(4,MFX)
      LONG = .FALSE.
      IF (KA.GT.1 ) LONG = .TRUE.
      KB = INFF(5, MFX)
      MS7=M7END-3
 53   CONTINUE
      CALL GETQQ(MFX,7,1,49,VZ)
      CALL STOR7(MS7,VZ,RW)
      CALL GETQQ(MFX,7,1,7,VW)
      CALL RXY(MFX,RX,RY,RW)
      CALL STXY(MS,RX,RY,RW)
      IF (.NOT.FLAG) GO TO 54
      II = 0
      CALL DASH1
      IF (KA .EQ. 1 .OR. KA .EQ. 3) GO TO 56
      WRITE(OUT3, 19)
      GO TO 57
  56  CONTINUE
      WRITE(OUT3, 20)
  57  CONTINUE
      IF (SIGFLG) GO TO 58
      WRITE (OUT3,16)
      GO TO 503
  58  CONTINUE
      WRITE(OUT3, 18)
      GO TO 503
 54   CONTINUE
      WRITE(OUT3,14)
 51   CONTINUE
      I = INFF(17,MB)
      CALL MIFILL (MB,1,I,NELS,MI,MISIZ)
      IF (NGO.EQ.2) GO TO 59
      CALL MMM(MS,NELS,MI)
      IF (KB .GE. 0) GO TO 59
      NELS = NELS +1
      MI(NELS) = MEND -6
      CALL REF(MEND-6, MS)
      ML(1) = MS
      ML(2) = MEND -6
      CALL MMM(MS, 2, ML)
  59  CONTINUE
      IF (KB .LT. 0) KB = -2 * KB
      KW = NELS + 1
      MI(KW) = MI(1)
      BSW = .FALSE.
      I1 = 0
      I2 = 0
      I3 = 0
      I4 = 0
      I5 = 0
      I41 = 0
      I43 = 0
      I51 = 0
      I53 = 0
      II = 0

C***********************************************************************

 100  CALL BET(MS,BETX,BETY,1)
      IF (II.EQ.0) BX0=BETX(2)
      IF (NGO.EQ.2) GO TO 503
 101  II = II + 1
C     IF I = KW, END OF BEAM LINE
      IF (II.GT.KW) GO TO 400
      NI = MI(II)
      IF (FLAG) GO TO 121
C     IF NOT AT BEGINNING OR END OF A BENDING MAGNET, CONTINUE
 110  IOP = CINFF(1,NI)
      IF (BSW) GO TO 300
      IF (IOP.NE.'MOVE') GO TO 115
      MQ = MDAT(NI,1)
      IOP = CINFF(1,MQ)
      IF (IOP.NE.'MAG')  GO TO 120
      CALL GETFL(MQ,1,6,P)
      GO TO 116
 115  IF (IOP.NE.'MAG') GO TO 120
C          GET MAGNET DATA.  L,K,RHO,OMEGA,GAMMA,DELTA
      CALL GETFL (NI,1,6,P)
 116  IF ( (BZ.NE.0) .OR. (NGO.EQ.2) )  GO TO 200
 120  CONTINUE

      IF (NGO.EQ.1) GOTO 122
 121  NF = M7END - 5
      CALL TRKCN(MS7,NI,VW,NP,0)
      NI = NF
      IF (KAF.EQ.0) GO TO 122

C  PRINT AIJ, BIB
 900  CONTINUE
      IPOS = II-1
      IF(IPOS.NE.0) GO TO 901
      MATI=IBLNK
      IF (FLAG) GO TO 903
      GO TO 902
 901  IF (.NOT.LONG) GO TO 122
      MK=MI(IPOS)
      MATI=CINFF(2,MK)
      IF (FLAG) GO TO 903
      IF (KA .NE. 4) GO TO 122
 902  CONTINUE
      WRITE(OUT3, 15) IPOS, MATI,
     1  AA(1,1),AA(1,2),AA(2,2),AA(1,3),AA(1,4),
     2  AA(2,3),AA(2,4),AA(3,3),AA(3,4),AA(4,4),
     3  BB(1,1),BB(1,2),BB(2,2),BB(1,3),BB(1,4),
     4  BB(2,3),BB(2,4),BB(3,3),BB(3,4),BB(4,4)
      GO TO 122
 903  CONTINUE
      WRITE(OUT3, 17) IPOS, MATI,
     1             CC(1,1),CC(1,2),CC(2,2),CC(1,3),CC(1,4),
     2             CC(2,3),CC(2,4),CC(3,3),CC(3,4),CC(4,4)
      IF (.NOT. LONG .OR. KA .EQ. 4) GO TO 400
      GO TO 503

 122  CONTINUE
      ML(1) = -NI
      ML(2) = MS
      ML(3) = NI
      CALL MMM(MS,3,ML)
      GO TO 100

C***********************************************************************

C  CALCULATE BILINEAR FORMS --- GENERALIZED ELLIPSE MATRICES
 503  CALL RTRV7(MS7,VZ,RW)
      H = GAM*E*E + 2*A*E*F + B*F*F
 500  DO 501 I=1,4
      EV(I,1) = CMPLX( VZ(I,2),VZ(I,3),KIND(0D0) )
      EV(I,3) = CMPLX( VZ(I,4),VZ(I,5),KIND(0D0) )
      EV(I,2) = CONJG( EV(I,1) )
      EV(I,4) = CONJG( EV(I,3) )
      DO 502 J=5,8
 502  EV(I,J) = (0D0,0D0)
 501  EV(I,I+4) = (1D0,0D0)
 600  DO 601 J=1,2
      I=2*J-1
 601  EI(J) = CONJG( VZ(I,6)*EV(2,I) - VZ(2,6)*EV(1,I)
     1             + VZ(3,6)*EV(4,I) - VZ(4,6)*EV(3,I) )
      EJ1 = EI(1)*EV(1,1)
      EJ3 = EI(1)*EV(3,1)
      EK1 = EI(2)*EV(1,3)
      EK3 = EI(2)*EV(3,3)
      CALL CMXDIV(EV,4,4,DET,4)
      DO 505 I=1,4
      DO 505 J=1,4
      AA(I,J) = 4 * REAL( CONJG(EV(1,I+4)) * EV(1,J+4) )
      BB(I,J) = 4 * REAL( CONJG(EV(3,I+4)) * EV(3,J+4) )
      IF (.NOT.FLAG) GO TO 505
      CC(I,J) = REP1*AA(I,J) + REP3*BB(I,J)
      UU = 0
      IF (J.EQ.I) UU = 1
      CC(I,J+4) = UU
 505  CONTINUE
      IF (.NOT. FLAG) GO TO 101
      CALL MXDIV(CC, 4, 4, DCC, 4)
      IF (.NOT. SIGFLG) GO TO 510
      DO 511 I = 1,4
      DO 511 J = 1,4
        CC(I,J) = CC(I, J+4)
 511  CONTINUE
      GO TO 101
 510  CONTINUE
      DO 506 I = 1,4
      DO 506 J = 1,4
        SPII = 0
        SPJJ = 0
        SPIJ = 0
        IF (KA .NE. 0 .AND. KA .NE. 3) GO TO 509
        SPII = VZ(I,6)*VZ(I,6)*SIGPSQ
        SPJJ = VZ(J,6)*VZ(J,6)*SIGPSQ
        SPIJ = VZ(I,6)*VZ(J,6)*SIGPSQ
 509  CONTINUE
      SII = CC(I, I+4) + SPII
      IF (J .EQ. I) GO TO 507
      SIJ = CC(I, J+4) + SPIJ
      SJJ = CC(J, J+4) + SPJJ
      YY = 2 * SIJ
      XX = SII - SJJ
      TIJ = 0
      IF (YY .EQ. 0 .AND. XX .EQ. 0) GO TO 508
      TIJ = ATAN2(YY, XX) / 2
 508  CONTINUE
      CC(I, J) = TIJ
      GO TO 506
 507  CONTINUE
      CC(I, I) = SQRT(SII)
 506  CONTINUE
      GO TO 101

C                  BENDING MAGNET -- ENTRANCE
 200  LH = L/2
      BR = BRHO*(1 + VW(6))
      IF (BZ .EQ. 0)  GO TO 262
      G = BZ/BR
      RHO = 1/G
      KX = P(2) + OM*G
      KK = SQRT(ABS(KX/P(3)))
      PHI = KK*L
      N = - P(2) * P(3) / (OM*OM)
      G2 = G*G
      G3 = G2*G
      AG3 = ABS(G3)
      AG3L = AG3*LH
      DFAC = G3*(1 - 2*N)
      EL2G = DFAC*L*L*G/24
      Q10 = DFAC*LH
      Q3 = 0
      THET = L * ABS(G)

C                  E0,E1 ARE ENTRANCE EXIT ANGLES
      ANG0=P(5)
      ANG1=P(6)
      IF ( INFF(6,NI) .EQ. 1)  GO TO 201
      E0 = P(5)*RADEG
      E1 = P(6)*RADEG
      GO TO 203
 201  E0 = THET/2
      E1=E0
 203  CONTINUE
      TE0 = TAN(E0)
      TE1 = TAN(E1)
      GAM =(1 + A*A)/ B

      IF (E0 .EQ. 0) GO TO 202
      F = F + E*TE0/RHO
      A = A - B*TE0/RHO
      GAM = (1 + A*A)/B
 202  K3R = 1 / (KK*KK*KK*RHO)

      IF (KX.LT.0) GOTO 230
      IF (KX.GT.0) GOTO 220

C                  COMPUTE V.  DO U AT END OF MAGNET

C                  FOR KX = 0
      CONTINUE
      RHO2 = RHO*RHO
      XL2=L*L
      XL3=L*XL2
      XL4=L*XL3
      XL5=L*XL4
      V = ( GAM*E*E + 2*A*E*F + B*F*F ) * L
     1   + ( A*E + B*F ) * XL2 / RHO
     2   + ( B/RHO - GAM*E - A*F ) * XL3 / ( 3*RHO )
     4   -   A * XL4 / ( 4*RHO2 )  +  GAM * XL5 / ( 20*RHO2 )
      GO TO 250

C                  FOR KX .GT. 0,  F MAGNET
 220  CONTINUE
      T = TAN(PHI/2)
      CS = COS(PHI)
      S = SIN(PHI)
      SC = S*CS
      VC1 = 1 - CS
      VC2 = PHI - S
      VC3 = 2*K3R
      VC4 = 1/(KK*B)
      V1 = L* (GAM*E*E + 2*A*E*F + B*F*F)
      V2 = VC3*E* (KK*A*VC1 - GAM*VC2)
      V3 = VC3*F* (KK*B*VC1 - A*VC2)
      VC5 = (PHI-SC)/2 - A*VC4*(2*VC1 - S*S)
      VC6 = (3*PHI - 4*S + SC)/2
      V4 = (B*K3R / RHO)* (VC5 + GAM*VC4*VC6/KK)
      V = V1 + V2 + V3 + V4
      GO TO 250

C                  FOR KX.LT.0    D MAGNET
 230  CONTINUE
      EX = EXP(PHI)
      EXM = EXP(-PHI)
      SH = (EX - EXM)/2
      CH = (EX + EXM)/2
      SC = SH*CH
      VC1 = 1 - CH
      VC2 = PHI - SH
      VC3 = 2*K3R
      VC4 = 1/(KK*B)
      VC5 = PHI - SC
      VC6 = VC1 + SH*SH/2
      VC7 = (3*PHI - 4*SH + SC)/2
      V1 = L* (GAM*E*E + 2*A*E*F + B*F*F)
      V2 = VC3*E*(KK*A*VC1 - GAM*VC2)
      V3 = VC3*F* (KK*B*VC1 - A*VC2)
      V4 = (B*K3R/RHO) *(VC5/2 + 2*A*VC4*VC6 - GAM*VC4*VC7/KK)
      V = V1 - V2 - V3 - V4

      GO TO 250

C                   QUADRUPOLE
 262  K = DB/BR
      EL2G = 0
      KSQ = K*K
      XK2L = KSQ*LH
      AK3L = ABS(K*KSQ*LH)
      TKSQL = 2*KSQ*LH
      W1=0
      GO TO 260

 250  IF (NGO.EQ.1) GOTO 251
 260  IF (BZ.NE.0)  GO TO 264
      RSQ = VW(1)*VW(1) + VW(3)*VW(3)
      RQ = SQRT(RSQ)
      G2L = RSQ*XK2L
      AG3L = RQ*RSQ*AK3L
      I2 = I2 + G2L
      I3 = I3 + AG3L
      Q1 = TKSQL*VW(1)
      Q3 = TKSQL*VW(3)
      GO TO 263
 264  Q1 = Q10 - TE0*G2
      IF (BSW)  Q1 = Q10 - TE1*G2
 263  I41 = I41 - Q1*AIMAG(EJ1) - Q3*AIMAG(EJ3) - EL2G*L
      I43 = I43 - Q1*AIMAG(EK1) - Q3*AIMAG(EK3)
      DO 261 I=1,4
      DO 261 J=1,4
      W1 = W1 + AA(I,J)*VZ(I,6)*VZ(J,6)*AG3L
 261  I53=I53 + BB(I,J)*VZ(I,6)*VZ(J,6)*AG3L
      W1 = W1 - H*AG3L
      IF (BSW)  GO TO 302


 251  CONTINUE
      BSW = .TRUE.
C     SAVE E TO COMPUTE U AT END OF MAGNET
      ESAV = E
      GO TO 120

C                  BENDING MAGNET EXIT.  CALCULATE U AND DO SUMMING.
 300  CONTINUE
      IF (NGO.EQ.1) GOTO 301
      IF (NGO.EQ.2) GOTO 260
 302  IF (OM.EQ.0)  GO TO 550
 301  IF (KX.LT.0) GOTO 330
      IF (KX.GT.0) GOTO 320
      U = (ESAV + E ) * L/2 - (L*L*L)/(12*RHO)
      GO TO 340
 320  T = TAN(PHI/2)
      U = (ESAV + E) *T/KK + K3R*(PHI - 2*T)
      GO TO 340
 330  T = TANH(PHI/2)
      U=(ESAV + E)*T/KK - K3R* (PHI - 2*T)
 340  CONTINUE
      I1 = I1 + G*U
      I2 = I2 + G*G*L
      I3 = I3 + AG3*L
      TR = (ESAV*TAN(E0) + E*TAN(E1))/(RHO*RHO)
      I4 = I4 + DFAC*U - TR
      I5 = I5 + AG3*V
 550  IF (NGO.EQ.2)  I51=I5+W1
      BSW = .FALSE.
C     GO BACK TO FIND OUT IF THIS ALSO BEGINS A BENDING MAGNET.
      GO TO 115

C***********************************************************************

C                  RF OUTPUT
 400  CONTINUE
      NRZZ = NRN
      IF (NGO .EQ. 1) GO TO 561
      IF (FLAG) GO TO 563
      FLAG =.TRUE.
 561  CONTINUE
      I1 = I1 * KB
      I2 = I2 * KB
      I3 = I3 * KB
      I4 = I4 * KB
      I5 = I5 * KB
      IF (NGO.EQ.1) GOTO 552
 553  I51 = I51 * KB
      I53 = I53 * KB
      I41 = I41 * KB
      I43 = I43 * KB
      D1 = I41/I2
      D3 = I43/I2
      J1 = 1 - D1
      J3 = 1 - D3
      J6 = 2 + D1 + D3
 552  CONTINUE
      LMTOT = PI2*RHO
      EL = PI2*R
      PC4 = PC**4
      ALPHA = ABS(I1/EL)
      GAMT = SQRT(1/ALPHA)
      U0 = CGAM*PC4*I2/PI2
      D = I4 /I2
      JX = 1 - D
      JE = 2 + D
      T0 = EL/C
      TAU0 = 4*PI *T0 /(CGAM*PC**3)
      TAUY = TAU0/I2
      TAUX = TAU0 / (I2 - I4)
      TAUE = TAU0 /(2*I2 + I4)

      IF (JE.LE.0.OR.I2.LE.0) THEN
        WRITE (OUT3,5000) JE,I2
 5000 FORMAT (2X,'*** JE OR I2 LESS THAN OR EQUAL TO ZERO.'/
     1  2X,'JE = ',F12.5,' I2 = ',F12.5/
     2  2X,'SQSIGE,SIGE,SIGPHI,SIGL,SIGBG,SIGDP,SIGPSQ GO TO ZERO',/
     3  2X,'PSI,EPLN,TAUQ,DPP GO TO ZERO.')
          SIGX = 0
          EPX0 = 0
        ELSE
          SQSIGE= ABS(CQP*PC4*I3/(JE*I2))
          SIGE = SQRT(SQSIGE)
        ENDIF
      FK = FREQ*T0

      CPHIS = U0/V0
      PHIS = ACOS(CPHIS)
      TE = SQRT(PI2*PC*T0*T0 / (ALPHA*FK*V0*SIN(PHIS)))
      SQE = 2*U0*(TAN(PHIS) - PHIS)/(PI*FK*ALPHA*PC)
      ASQE = ABS(SQE)
      EPSM = PC*SQRT(ASQE)
      PSI = (EPSM/SIGE)**2/2
      IF (PSI .LE. 70) GO TO 556
      PSITRU = PSI
      PSI = 70
      WRITE(OUT3, 1) PSITRU, PSI
 556  CONTINUE
      TAUQ =(TAUE/2)*EXP(PSI) /PSI   
      SIGPHI = SIGE*SQRT (PI2*FK*ALPHA / (V0*SIN(PHIS)*PC))
      SIGL = SIGPHI*R/FK
      PHISD = PHIS*180/PI

C                  COMPUTE EPSILONS FOR EMITTANCE AND STORE
      BETX(2)=BX0
      IF (JX.LE.0.OR.I2.LE.0) THEN
        WRITE (OUT3,5001) JX,I2
 5001 FORMAT (2X,'*** JX OR I2 LESS THAN OR EQUAL TO ZERO.'/
     1  2X,'JX = ',F12.5,' I2 = ',F12.5/
     2  2X,'SIGXOB,SIGX,EPX0 ARE NOT CALCULATED.'/
     3  2X,'SIGX,EPX0 SET TO 0.'/
     4  5X,'THIS CAUSES EPX,EPY,EPXN,EPYN TO BE 0.')
          SIGX = 0
          EPX0 = 0
        ELSE
          SIGXOB = SQRT (CQP*PC*PC*I5 / (JX*I2))
          SIGX = SIGXOB * SQRT(BETX(2))
          EPX0 = SIGX*SIGX/BETX(2)
        ENDIF
      SQRT6 = 6
      SQRT6 = SQRT(SQRT6)
      IF (FLAG .AND. FKAP .EQ. 0) FKAP = .0001D0
      EPX = (1 - FKAP*FKAP)*EPX0
      EPY = FKAP*FKAP*EPX0
      IF (NGO.EQ.1) GOTO 554
 555  CK = CQP*PC*PC/I2
      EP1  = CK*I51/J1
      EP3  = CK*I53/J3
      EP3S = EP3
      IF (EP3 .EQ. 0) EP3S = EPY
      REP1 = 1 / EP1
      REP3 = 1 / EP3S
 554  CONTINUE
      SIGBG = SIGE/RME
      EPLN = SIGBG * SIGL
      WRITE (OUT3,5003)EPY,BETY(2)
 5003 FORMAT (2X,'FOR SIGY -- EPY,BETY(2) ',2F12.5)
      SIGY = SQRT( EPY * BETY(2) )
      SIGDP = SIGE/PC
      SIGPSQ = SIGDP * SIGDP
      DPP = SQRT6*SIGDP
      BETGAM = PC/RME
      EPXN = EPX * BETGAM
      EPYN = EPY * BETGAM

C            STORE EPX,EPY,DP/P,EPLN
      CALL STOQ(M,1,4,EM)
 562  IF (FLAG) GO TO 53
 563  CONTINUE


      CALL DASH1
      WRITE (OUT3,2) PC,GAMT,R,U0
      WRITE (OUT3,4) FREQ,T0,V0,TAUX
      WRITE (OUT3,6) RHO,TAUY,ALPHA,TAUE
      WRITE (OUT3,3) D,SIGX,PHISD,TAUQ
      WRITE (OUT3,5) TE,SIGPHI,EPSM,SIGL
      WRITE (OUT3,7) XI,DPP,SIGDP
      WRITE (OUT3,11) SIGE,SIGBG
      WRITE(OUT3,10) FK,BETGAM
      WRITE (OUT3,9) I1,I2,I3,I4,I41,I43,I5,I51,I53
      WRITE (OUT3,12) JX,JZ,JE,J1,J3,J6
      WRITE (OUT3,8) EPXN,EPYN,EPLN,EPX,EPY,EP1,EP3
      CALL DASH1

C***********************************************************************
C                  FORMATS
 1    FORMAT(' PSI =', E13.5, ' ---TAUQ IS .GT. VALUE PRINTED',
     1 ' BELOW, WHICH CORRESPONDS TO PSI = ', E13.5)
 2    FORMAT (' MOMENTUM',22X,'   P=',E12.5,' GEV/C',10X,' TRANSITION GA
     1MMA',10X,'GAMT=',E12.5,/,' AVERAGE RADIUS',17X,'  R=',E12.5,
     2 ' METERS',9X,' SYNCHROTRON RADIATION',7X,'U0=',E12.5,' GEV/TURN')
 3    FORMAT (' DAMPING PARTITION',16X,'D=',E12.5,16X,
     1' SIGMAX(0-COUPLING)',8X,'SIGX=',E12.5,' METERS',
     A    /,' PHASE ANGLE',19X,
     2'PHIS=',E12.5,' DEGREES',8X,' QUANTUM LIFETIME',10X,'TAUQ=',E12.5,
     3 ' SECONDS')
 4    FORMAT (' R F FREQUENCY',18X,'  F=',E12.5,' HZ',13X,' CIRCULATION
     1 PERIOD',10X,'T0=',E12.5,' SECONDS',/,' R F PEAK VOLTS',18X,'V0=',
     2E12.5,' GV',14X,'HORIZONTAL DAMPING',8X,'TAUX=',E12.5,' SECONDS')
 5    FORMAT (' ENERGY OSCILLATION PERIOD',5X,'  TE=',E12.5,' SECONDS',
     18X,' BUNCH LENGTH',12X,'SIGPHI=',E12.5,' RADIANS',/,
     2' ENERGY APERTURE',15X,'EPSM=',E12.5,' GEV  ',10X,
     3' BUNCH LENGTH',14X,'SIGL=',E12.5,' METERS')
 6    FORMAT (' EFFECTIVE RADIUS',17X,'R=',E12.5,' METERS',9X,' VERTICAL
     1 DAMPING',10X,'TAUY=',E12.5,' SECONDS',/,' MOMENTUM COMPACTION',
     210X,'ALPHA=',E12.5,17X,'ENERGY DAMPING',12X,'TAUE=',E12.5,
     3 ' SECONDS')
 7    FORMAT(' (EPSM',2H**,'2/SIGE',2H**,'2)/2',11X,'  XI=',E12.5,17X,
     1  'MOMENTUM SPRD',1H','SQRT(6)',5X,'DP/P=',E12.5,/,
     2 ' SIGMA(DP/P)',18X,'SIGDP=',E12.5)
 9    FORMAT(/' I1=',E12.5 /' I2=',E12.5/' I3=',E12.5/' I4=',E12.5,
     1 14X,'I41 = ',E12.5,14X,'I43 = ',E12.5
     2 /' I5=',E12.5,14X,'I51 = ',E12.5,14X,'I53 = ',E12.5 )
 11   FORMAT (31X,'SIGE=',E12.5,42X,'SIGBG=',E12.5)
 10   FORMAT (/5X,'K(HARMONIC NO.) = ',E12.5,20X,'BETAGAMMA = ',E12.5)
 8    FORMAT (///10X,'EMITTANCES (METER RADIANS)'/10X,'EPXN = ',E12.5,
     1 7X,'EPYN = ',E12.5,7X,'EPLN = ',E12.5/10X,' EPX = ',E12.5,7X,
     2  ' EPY = ',E12.5/11X,'EP1 = ',E12.5,7X,' EP3 = ',E12.5/)
 12   FORMAT (/' JX = ',F12.5,14X,'JY = ',F12.5,14X,'JE = ',F12.5/,
     1         ' J1 = ',F12.5,14X,'J3 = ',F12.5,14X,'J6 = ',F12.5)
 13   FORMAT (1X,'CYEM1'/)
 14   FORMAT(2X,'POS',11X,'A11',9X,'A12',9X,'A22',9X,'A13',9X,
     1 'A14',9X,'A23',9X,'A24',9X,'A33',9X,'A34',9X,'A44'/
     2 16X,'B11',9X,'B12',9X,'B22',9X,'B13',9X,'B14',9X,'B23',
     3 9X,'B24',9X,'B33',9X,'B34',9X,'B44'/ )
 15   FORMAT(/1X,I4,1X,A5,1X,10F12.7/ 12X,10F12.7)
 16   FORMAT (1X,'BEAM ELLIPSE MATRIX --- SIJ = SIGMA(I,J),',
     1 '  RII = SQRT(SII),  TIJ = ATAN( 2.SIJ / (SII-SJJ) ) / 2 '/
     2       2X,'POS',11X,'R11',9X,'R22',9X,'T13',
     3       9X,'T14',9X,'T23',9X,'T24',9X,'R33',9X,'T34',9X,'R44'/)
  18  FORMAT(' BEAM ELLIPSE MATRIX --- SIJ = SIGMA(I,J) ' /
     1       '  POS', 11X, 'S11', 9X, 'S12', 9X, 'S22', 9X, 'S13',
     2       9X,'S14',9X,'S23',9X,'S24',9X,'S33',9X,'S34',9X,'S44' /)
 17   FORMAT (1X,I4,1X,A5,1X,10E12.4)
  19  FORMAT('    (BETATRON PART OF SIGMA MATRIX)  ')
  20  FORMAT('    (TOTAL SIGMA MATRIX)    ')


      RETURN
      END
